#[repr(u8)]pub enum ObjectPermission {
ImmutableUsage = 1,
MutableUsage = 2,
Write = 4,
Delete = 8,
InternalTransfer = 16,
PublicTransfer = 32,
Wrap = 64,
}Expand description
A single permission that can be granted on a party-owned object.
Bit layout (u8):
7 6 5 4 3 2 1 0
_ W P T D M U IIBit 0:Self::ImmutableUsageis required for immutable usage at signingUBit 1:Self::MutableUsageis required for mutable usage at signing- It is also required for any additional permissions below
MBit 2:Self::Writeallows for the value of the object to be changedDBit 3:Self::Deleteallows for the object to be deletedTBit 4:Self::InternalTransferallows for usage of the internal transfer functionsPBit 5:Self::PublicTransferallows for usage of public transfer functionsWBit 6:Self::Wrapallows for the object to be wrapped
Variants
ImmutableUsage = 1
MutableUsage = 2
Write = 4
Delete = 8
InternalTransfer = 16
PublicTransfer = 32
Wrap = 64
Implementations