pub enum Owner {
AddressOwner(SuiAddress),
ObjectOwner(SuiAddress),
Shared {
initial_shared_version: SequenceNumber,
},
Immutable,
ConsensusAddressOwner {
start_version: SequenceNumber,
owner: SuiAddress,
},
Party {
start_version: SequenceNumber,
permissions: Party,
},
}Variants
AddressOwner(SuiAddress)
Object is exclusively owned by a single address, and is mutable.
ObjectOwner(SuiAddress)
Object is exclusively owned by a single object, and is mutable. The object ID is converted to SuiAddress as SuiAddress is universal.
Object is shared, can be used by any address, and is mutable.
Immutable
Object is immutable, and hence ownership doesn’t matter.
ConsensusAddressOwner
Object is exclusively owned by a single address and sequenced via consensus.
Fields
start_version: SequenceNumberThe version at which the object most recently became a consensus object.
This serves the same function as initial_shared_version, except it may change
if the object’s Owner type changes.
owner: SuiAddressParty
Object is sequenced via consensus with per-address permissions.
Each address can be granted a subset of ObjectPermission flags.
Addresses not explicitly listed fall back to the default permissions.
Fields
start_version: SequenceNumberThe version at which the object most recently became a party object.
Serves the same function as initial_shared_version, except it may change
if the object’s Owner type changes.
Implementations
Sourceimpl Owner
impl Owner
pub fn get_address_owner_address(&self) -> SuiResult<SuiAddress>
pub fn get_owner_address(&self) -> SuiResult<SuiAddress>
pub fn start_version(&self) -> Option<SequenceNumber>
pub fn is_immutable(&self) -> bool
pub fn is_address_owned(&self) -> bool
pub fn is_child_object(&self) -> bool
pub fn is_consensus(&self) -> bool